@@ -309,6 +309,7 @@ module Rabbit
       def generate_dot_gitignore
         create_file(".gitignore") do |dot_gitignore|
           dot_gitignore.puts(<<-EOD)
+.DS_Store
 /.tmp/
 /pkg/
 /pdf/
@@ -383,9 +384,9 @@ require "rabbit/task/slide"
 spec = nil
 Rabbit::Task::Slide.new do |task|
   spec = task.spec
-  # task.spec.files += Dir.glob("doc/**/*.*")
-  # task.spec.files -= Dir.glob("private/**/*.*")
-  # task.spec.add_runtime_dependency("YOUR THEME")
+  # spec.files += Dir.glob("doc/**/*.*")
+  # spec.files -= Dir.glob("private/**/*.*")
+  # spec.add_runtime_dependency("YOUR THEME")
 end
 
 desc "Tag #{spec.version}"
@@ -460,7 +461,7 @@ end
           ["author",         @author_conf.name,  _("AUTHOR")],
           ["institution",    nil,                _("INSTITUTION")],
           ["content-source", nil,                _("EVENT NAME")],
-          ["date",           presentation_date,  Time.now.strftime("%Y/%m/%d")],
+          ["date",           presentation_date,  Time.now.strftime("%Y-%m-%d")],
           ["allotted-time",  @allotted_time,     "5m"],
           ["theme",          nil,                "default"],
         ]
