@@ -1,8 +1,18 @@
+require "English"
+
+require "rabbit/parser/pause-support"
+require "rabbit/parser/ext/blockdiag"
+require "rabbit/parser/ext/coderay"
+require "rabbit/parser/ext/escape"
+require "rabbit/parser/ext/image"
+require "rabbit/parser/ext/tex"
+
 module Rabbit
   module Parser
     class Markdown
       class Converter
         include Element
+        include PauseSupport
 
         def initialize(canvas)
           @canvas = canvas
@@ -11,15 +21,17 @@ module Rabbit
           @slide_property_mode = false
         end
 
-        def convert(element)
-          __send__("convert_#{element.type}", element)
+        def convert(element, context=nil)
+          method_name = "convert_#{element.type}"
+          method_name << "_#{context}" if context
+          __send__(method_name, element)
         end
 
         private
-        def convert_container(element)
+        def convert_container(element, context=nil)
           elements = []
           element.children.each do |child|
-            element = convert(child)
+            element = convert(child, context)
             case element
             when nil, :no_element
               # ignore
@@ -39,7 +51,7 @@ module Rabbit
               next
             when nil
               mode = :ignore
-            when Slide
+            when Element::Slide
               target = content.body
               @canvas << content
               mode = :display
@@ -59,6 +71,7 @@ module Rabbit
               end
             end
           end
+          burn_out_pause_targets
         end
 
         def convert_header(element)
@@ -69,7 +82,7 @@ module Rabbit
             if @slides.empty?
               @slide = TitleSlide.new(Title.new(contents))
             else
-              @slide = Slide.new(HeadLine.new(contents))
+              @slide = Element::Slide.new(HeadLine.new(contents))
               @slide << Body.new
             end
             @slides << @slide
@@ -114,8 +127,14 @@ module Rabbit
           list
         end
 
+        def create_paragraph(elements)
+          paragraph = Paragraph.new(elements)
+          register_pause(paragraph) if paragraph.have_wait_tag?
+          paragraph
+        end
+
         def convert_dt(element)
-          DescriptionTerm.new(Paragraph.new(convert_container(element)))
+          DescriptionTerm.new(create_paragraph(convert_container(element)))
         end
 
         def convert_dd(element)
@@ -130,17 +149,61 @@ module Rabbit
               raise ParseError,
                       _("multiple ![alt]{image} in a paragraph isn't supported.")
             else
-              Paragraph.new(convert_container(element))
+              create_paragraph(convert_container(element))
             end
           end
         end
 
-        def convert_ul(element)
-          ItemList.new(convert_container(element))
+        def create_list(list_class, contents)
+          list = list_class.new
+          contents.each do |content|
+            list << content
+            if block_given?
+              yield(list, content)
+            end
+          end
+          list
         end
 
-        def convert_li(element)
-          ItemListItem.new(convert_container(element))
+        def create_list_item(list_item_class, contents)
+          list_item = list_item_class.new(contents)
+
+          waited_paragraphs = list_item.elements.find_all do |element|
+            element.is_a?(Paragraph) and element.have_wait_tag?
+          end
+          unless waited_paragraphs.empty?
+            waited_paragraphs.each do |paragraph|
+              paragraph.default_visible = true
+              paragraph.clear_theme
+              unregister_pause(paragraph)
+            end
+
+            list_item.default_visible = false
+            list_item.clear_theme
+            register_pause(list_item)
+          end
+
+          list_item
+        end
+
+        def convert_ul(element)
+          create_list(ItemList, convert_container(element, "ul"))
+        end
+
+        def convert_li_ul(element)
+          create_list_item(ItemListItem, convert_container(element))
+        end
+
+        def convert_ol(element)
+          i = 1
+          create_list(EnumList, convert_container(element, "ol")) do |list, item|
+            item.order = i
+            i += 1
+          end
+        end
+
+        def convert_li_ol(element)
+          create_list_item(EnumListItem, convert_container(element))
         end
 
         def convert_smart_quote(element)
@@ -198,12 +261,42 @@ module Rabbit
 
         def convert_codeblock(element)
           content = element.value.chomp
+          language = detect_codeblock_language(element)
+          if language
+            converted = convert_codeblock_language(element, language, content)
+          end
+          converted || PreformattedBlock.new(PreformattedText.new(text(content)))
+        end
+
+        def detect_codeblock_language(element)
           lang = element.attr["lang"]
-          if lang
-            highlighted = Ext::CodeRay.highlight(lang, content, @canvas.logger)
-            return highlighted if highlighted
+          return lang if lang
+
+          language = element.attr["language"]
+          return language if language
+
+          klass = element.attr["class"]
+          if klass and /\Alanguage-/ =~ klass
+            return $POSTMATCH
+          end
+
+          nil
+        end
+
+        def convert_codeblock_language(element, language, content)
+          case language
+          when "blockdiag"
+            args = [@canvas, content]
+            Ext::Image.make_image_from_file(*args) do |src_file_path|
+              [
+                Ext::BlockDiag.make_image(src_file_path, element.attr, @canvas),
+                element.attr,
+              ]
+            end
+          else
+            logger = @canvas.logger
+            Ext::CodeRay.highlight(language, content, logger)
           end
-          PreformattedBlock.new(PreformattedText.new(text(content)))
         end
 
         def convert_blockquote(element)
@@ -226,7 +319,7 @@ module Rabbit
             end
             body["background-image"] = uri
             options.each do |name, value|
-              name = name.to_s.gsub(/_/, '-')
+              name = name.to_s.gsub(/_/, "-")
               body["background-image-#{name}"] = value
             end
             :no_element
@@ -253,7 +346,7 @@ module Rabbit
 
         def convert_a(element)
           ref = ReferText.new(convert_container(element))
-          ref.to = element.attr['href']
+          ref.to = element.attr["href"]
           ref
         end
 
@@ -262,7 +355,11 @@ module Rabbit
         end
 
         def convert_codespan(element)
-          Code.new(Text.new(element.value))
+          Code.new(text(element.value))
+        end
+
+        def convert_wait(element)
+          WaitTag.new
         end
       end
     end
