@@ -4,70 +4,15 @@ require "stringio"
 require "rabbit/image-data-loader"
 require "rabbit/renderer/kernel"
 
-module Cairo
-  class Context
-    unless instance_methods.include?("rounded_rectangle")
-      def rounded_rectangle(x, y, width, height, x_radius, y_radius=nil)
-        x1 = x
-        x2 = x1 + width
-        y1 = y
-        y2 = y1 + height
-
-        y_radius ||= x_radius
-
-        x_radius = [x_radius, width / 2].min
-        y_radius = [y_radius, height / 2].min
-
-        xr1 = x_radius
-        xr2 = x_radius / 2.0
-        yr1 = y_radius
-        yr2 = y_radius / 2.0
-
-        move_to(x1 + xr1, y1)
-        line_to(x2 - xr1, y1)
-        curve_to(x2 - xr2, y1, x2, y1 + yr2, x2, y1 + yr1)
-        line_to(x2, y2 - yr1)
-        curve_to(x2, y2 - yr2, x2 - xr2, y2, x2 - xr1, y2)
-        line_to(x1 + xr1, y2)
-        curve_to(x1 + xr2, y2, x1, y2 - yr2, x1, y2 - yr1)
-        line_to(x1, y1 + yr1)
-        curve_to(x1, y1 + yr2, x1 + xr2, y1, x1 + xr1, y1)
-        close_path
-      end
-    end
-  end
-end
-
 module Rabbit
   module Renderer
     module Engine
       module Cairo
         include Kernel
 
-        @@rsvg_available = nil
-        @@poppler_available = nil
-
         class << self
-          def available_with_gdk?
-            Gdk.respond_to?(:cairo_available?) and Gdk.cairo_available?
-          end
-
-          def available_with_gdk_pixbuf?
-            Gdk::Pixbuf.respond_to?(:cairo_available?) and
-              Gdk::Pixbuf.cairo_available?
-          end
-
-          def available_with_pango?
-            Pango.respond_to?(:cairo_available?) and Pango.cairo_available?
-          end
-
           def priority
-            if available_with_gdk? and available_with_gdk_pixbuf? and
-                available_with_pango?
-              100
-            else
-              -100
-            end
+            100
           end
         end
 
@@ -300,13 +245,6 @@ module Rabbit
           end
         end
 
-        def rsvg_available?
-          if @@rsvg_available.nil?
-            @@rsvg_available = RSVG.cairo_available?
-          end
-          @@rsvg_available
-        end
-
         def draw_rsvg_handle(handle, x, y, params={})
           x, y = from_screen(x, y)
           dim = handle.dimensions
@@ -322,13 +260,6 @@ module Rabbit
                                       params)
         end
 
-        def poppler_available?
-          if @@poppler_available.nil?
-            @@poppler_available = Poppler.cairo_available?
-          end
-          @@poppler_available
-        end
-
         def draw_poppler_page(page, x, y, params={})
           x, y = from_screen(x, y)
           w, h = page.size
