@@ -15,8 +15,6 @@ module Rabbit
     module Print
       class Cairo
         include Engine::Cairo
-        alias_method :cairo_rsvg_available?, :rsvg_available?
-        alias_method :cairo_poppler_available?, :poppler_available?
         include Base
 
         class << self
@@ -28,7 +26,7 @@ module Rabbit
             end
           end
         end
-        
+
         def initialize(canvas)
           super
           init_paper
@@ -44,19 +42,19 @@ module Rabbit
           return if canceled
           @context.target.finish
         end
-        
+
         def pre_parse
         end
-        
+
         def post_parse
         end
-        
+
         def post_apply_theme
         end
-        
+
         def post_move(old_index, index)
         end
-        
+
         def post_move_in_slide(old_index, index)
         end
 
@@ -75,14 +73,6 @@ module Rabbit
           draw_rectangle(true, x, y, w, h, @background)
         end
 
-        def rsvg_available?
-          cairo_rsvg_available?
-        end
-
-        def poppler_available?
-          cairo_poppler_available?
-        end
-
         private
         def init_paper
           default_width_mm = 360
@@ -90,7 +80,7 @@ module Rabbit
           @page_width = @paper_width || default_width_mm
           @page_height = @paper_height || default_height_mm
         end
-        
+
         def init_color
           super
           @foreground = make_color("black")
@@ -126,6 +116,9 @@ module Rabbit
             surface = ::Cairo::SVGSurface.new(*args)
             surface.restrict_to_version(::Cairo::SVG_VERSION_1_2)
             surface
+          when /\.cs/i
+            args[0] = ::Cairo::ScriptDevice.new(args[0])
+            ::Cairo::ScriptSurface.new(*args)
           else
             @canvas.logger.warn(_("can't find printer for %s") % filename)
             args[0] = "default.ps"
